@@ -135,14 +135,13 @@ class DotsCodeGenerator:
         absFileName = self.outputPath + "/" + fileName
         absTempFileName = absFileName + ".tmp"
 
-        if self.verbose:
-            eprint("    gen " + fileName)
         jinja = DdlTemplate(self.templatePath, absTempFileName)
         jinja.render(key, fs)
 
         # Check if tempFileName is different to fileName, only overwrite if different
         if not self.isFileEqual(absTempFileName, absFileName):
-            os.rename(absTempFileName, absFileName)
+            eprint("created " + fileName)
+            os.replace(absTempFileName, absFileName)
         else:
             os.remove(absTempFileName)
 
@@ -189,7 +188,7 @@ class DotsCodeGenerator:
         needToImport = set(s["imports"]) & set(structTypes)
         # Add missing imports for struct
         needToImport = needToImport | set(structTypes)
-        fs["imports"] = list(needToImport)
+        fs["imports"] = sorted(list(needToImport))
 
         outputNames = self.outputNames(struct["name"], self.struct_templates)
         
